==> apache-ignite-3.0.0-src.zip: apache-ignite-3.0.0-src/modules/client/src/main/java/org/apache/ignite/internal/client/ClientChannelFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.client;

import java.util.concurrent.CompletableFuture;
import java.util.function.Consumer;
import org.apache.ignite.internal.client.io.ClientConnectionMultiplexer;

/**
 * Client channel factory.
 */
@FunctionalInterface
public interface ClientChannelFactory {
    /**
     * Creates a new client channel.
     *
     * @param cfg Configuration.
     * @param multiplexer Multiplexer.
     * @param metrics Metric source.
     * @return Channel future.
     */
    CompletableFuture<ClientChannel> create(
            ClientChannelConfiguration cfg,
            ClientConnectionMultiplexer multiplexer,
            ClientMetricSource metrics,
            Consumer<Long> assignmentChangeListener,
            Consumer<Long> observableTimestampListener);
}

==> apache-ignite-3.1.0-src.zip: apache-ignite-3.1.0-src/modules/client/src/main/java/org/apache/ignite/internal/client/ClientChannelFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.client;

import java.util.concurrent.CompletableFuture;
import java.util.function.Consumer;
import org.apache.ignite.internal.client.io.ClientConnectionMultiplexer;

/**
 * Client channel factory.
 */
@FunctionalInterface
public interface ClientChannelFactory {
    /**
     * Creates a new client channel.
     *
     * @param cfg Configuration.
     * @param multiplexer Multiplexer.
     * @param metrics Metric source.
     * @return Channel future.
     */
    CompletableFuture<ClientChannel> create(
            ClientChannelConfiguration cfg,
            ClientConnectionMultiplexer multiplexer,
            ClientMetricSource metrics,
            Consumer<Long> assignmentChangeListener,
            Consumer<Long> observableTimestampListener,
            ClientTransactionInflights inflights);
}
